@@ -14,11 +14,11 @@ HTML::Truncate - (alpha software!) truncate HTML by text or raw character count
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 ABSTRACT
 
@@ -26,8 +26,8 @@ When working with text it is convenient and common to want to truncate
 strings to make them fit a desired context. E.g., you might have a
 menu that is only 100px wide and prefer text doesn't wrap so you'd
 truncate it around 15-30 characters, depending on preference and
-typeface size. This is trivial with plain text and C<substr> but with
-HTML it is somewhat difficult because whitespace has fluid
+typeface size. This is trivial with plain text using C<substr> but
+with HTML it is somewhat difficult because whitespace has fluid
 significance and open tags that are not properly closed destroy
 well-formedness and can wreck an entire layout.
 
@@ -37,19 +37,23 @@ open at the point of truncation.
 
 =head1 SYNOPSIS
 
- # OO
+ use strict;
  use HTML::Truncate;
- my $readmore = '<a href="/full-article">readmore</a>';
+
+ my $html = '<p><i>We</i> have to test <b>something</b>.</p>';
+ my $readmore = '... <a href="/full-article">[readmore]</a>';
+
  my $html_truncate = HTML::Truncate->new();
- $html_truncate->chars(200);
+ $html_truncate->chars(20);
  $html_truncate->ellipsis($readmore);
- print $html_truncate->($bunch_of_html);
+ print $html_truncate->truncate($html), $/;
 
  # or
+
  my $ht = HTML::Truncate->new(utf => 1,
                               chars => 1_000,
                               );
- print $html_truncate->($html);
+ print $ht->truncate($html), $/;
 
 =head1 XHTML
 
@@ -364,7 +368,12 @@ sub truncate {
 =head2 $ht->add_skip_tags( qw( tag list ) )
 
 Put one or more new tags into the list of those to be ommitted from
-truncated output.
+truncated output. An example of when you might like to use this is if
+you're thumbnailing articles and they start with C<< <h1>title</h1> >>
+or such before the article body. The heading level would be absurd
+with a list of excerpts so you could drop it completely this way--
+
+ $ht->add_skip_tags( 'h1' );
 
 =cut
 
@@ -381,7 +390,7 @@ sub add_skip_tags {
 
 =head2 $ht->dont_skip_tags( qw( tag list ) )
 
-asdf
+Takes tags out of the current list to be omitted from truncated output.
 
 =cut
 
@@ -414,17 +423,16 @@ sub _load_chars_from_percent {
 
 =head1 TO DO
 
-Make the skip and tag stuff available through methods so it can be
-altered by the user. Many more tests. Go through entire dist and make
-sure everything is kosher (autogenerated with the lovely
-L<Module::Starter>). Reorganize POD to read in best learning order.
-Make sure the padding check is working across wide range of cases. POD
-to describe various ways to use it including a TT2 filter. "html"
-style truncating.
+Many more tests. Allow new stand alone tags to be added. Go through
+entire dist and make sure everything is kosher (autogenerated with the
+lovely L<Module::Starter>). Reorganize POD to read in best learning
+order. Make sure the padding check is working across wide range of
+cases. POD to describe various ways to use it including a TT2 filter.
+"html" style truncating.
 
 =head1 AUTHOR
 
-Ashley Pond V, C<< <ashley@cpan.org> >>
+Ashley Pond V, C<< <ashley@cpan.org> >>.
 
 =head1 LIMITATIONS
 
